@@ -14,7 +14,7 @@ from typing import Optional, Any
 
 
 class ArgIdentifier(ast.NodeVisitor):
-    """ """
+    """description"""
 
     def __init__(
         self,
@@ -86,33 +86,36 @@ class ArgIdentifier(ast.NodeVisitor):
 
 
 def get_arg_names(func_name: str, *, verbose=False, max_num_intermediate_unnamed_elements=1) -> Optional[str]:
-    """ """
+    """description"""
     import inspect
     import textwrap
     import ast
 
     caller_frame = inspect.currentframe().f_back.f_back
-    caller_src_code_lines = inspect.getsourcelines(caller_frame)
-    fai = ArgIdentifier(
-        func_name,
-        verbose=verbose,
-        max_num_intermediate_unnamed_elements=max_num_intermediate_unnamed_elements,
-    )
-    fai.visit(ast.parse(textwrap.dedent("".join(caller_src_code_lines[0]))))
-    if func_name in fai.result:
-        offset = 0
-        if caller_src_code_lines[1]:
-            offset = caller_src_code_lines[1] - 1
-        idx = caller_frame.f_lineno - offset
-        if idx in fai.result[func_name]:
-            return fai.result[func_name][idx]
+    try:
+        caller_src_code_lines = inspect.getsourcelines(caller_frame)
+        fai = ArgIdentifier(
+            func_name,
+            verbose=verbose,
+            max_num_intermediate_unnamed_elements=max_num_intermediate_unnamed_elements,
+        )
+        fai.visit(ast.parse(textwrap.dedent("".join(caller_src_code_lines[0]))))
+        if func_name in fai.result:
+            offset = 0
+            if caller_src_code_lines[1]:
+                offset = caller_src_code_lines[1] - 1
+            idx = caller_frame.f_lineno - offset
+            if idx in fai.result[func_name]:
+                return fai.result[func_name][idx]
+            elif verbose:
+                print(
+                    f'Unexpected line number: {idx}, probably a wrong alias "{func_name}" was supplied, found {fai.result[func_name]}, in {inspect.getsourcefile(caller_frame)}'
+                )
         elif verbose:
-            print(
-                f'Unexpected line number: {idx}, probably a wrong alias "{func_name}" was supplied, found {fai.result[func_name]}, in {inspect.getsourcefile(caller_frame)}'
-            )
-    elif verbose:
-        print(f"{func_name} was not found in {fai.result}")
-    return None
+            print(f"{func_name} was not found in {fai.result}")
+    except Exception as e:
+        print(e)
+    return
 
 
 def ge_arg_names_recurse() -> Optional[str]:
@@ -127,12 +130,28 @@ def ge_arg_names_recurse() -> Optional[str]:
 
 
 def cprinta(*v: Any, writer: callable = print, deliminator: str = ":") -> None:
+    """
+
+    :param v:
+    :type v:
+    :param writer:
+    :type writer:
+    :param deliminator:
+    :type deliminator:
+    """
     if isinstance(v, str) and v.strip() == "":
         v = '""'
     writer(f"{get_arg_names('cprinta')}{deliminator}", v)
 
 
 def cprintz(*v: Any, writer: callable = print) -> None:
+    """
+
+    :param v:
+    :type v:
+    :param writer:
+    :type writer:
+    """
     if isinstance(v, str) and v.strip() == "":
         v = '""'
 
@@ -143,6 +162,7 @@ def cprintz(*v: Any, writer: callable = print) -> None:
 if __name__ == "__main__":
 
     def siajd():
+        """description"""
         s = ""
         aisjd = s
         sioj = 4
