@@ -1,6 +1,12 @@
 from typing import Mapping, Iterable, Hashable, Dict
 
-__all__ = ["invert_mapping", "invert_dict", "AppendingDict", "pivot_dict_object", "pivot_dict"]
+__all__ = [
+    "invert_mapping",
+    "invert_dict",
+    "AppendingDict",
+    "pivot_dict_object",
+    "pivot_dict",
+]
 
 
 def append_to_dict(d: Dict, key, value) -> Dict:
@@ -29,6 +35,13 @@ class AppendingDict(Dict):  # appending_dict = collections.defaultdict(list)
             super().__setitem__(key, [value])
 
 
+def recurse_mapping(a: Mapping, call: callable = print) -> None:
+    for k, v in a.items():
+        if isinstance(v, Mapping):
+            recurse_mapping(v)
+        call(v)
+
+
 def invert_mapping(m: Mapping) -> Mapping:
     """
     Invert a mapping
