@@ -6,7 +6,7 @@ __doc__ = r"""
 
            Created on 18/03/2020
            """
-__all__ = ["default_datetime_repr"]
+__all__ = ["default_datetime_repr", "now_repr"]
 
 import datetime
 
@@ -26,7 +26,11 @@ def default_datetime_repr(date: datetime, str_format: str = DEFAULT_REPRESENTATI
 
 
 def now_repr() -> str:
-    """ """
+    """
+
+    :return:
+    :rtype:
+    """
     return default_datetime_repr(datetime.datetime.now())
 
 
