@@ -1,15 +1,15 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+
+__author__ = "Christian Heider Nielsen"
+__doc__ = ""
+
 __all__ = [
     "OrdinalIndexingDictMixin",
 ]
 
 
-#  Copyright (c) 2021. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
-#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
-#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
-#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
-#  Vestibulum commodo. Ut rhoncus gravida arcu.
-
-
 class OrdinalIndexingDictMixin:
     """
     Mixin class for indexing a class instance __dict__ (SortedDict) with both integer (ordinal) indexing or
